@@ -1,6 +1,7 @@
 from sqlalchemy import Column
 from sqlalchemy import Integer
 from sqlalchemy import String
+from sqlalchemy.dialects.mysql import TINYINT
 from marshmallow import fields
 from marshmallow import Schema
 
@@ -14,6 +15,7 @@ class User(Base):
     name = Column(String(30), nullable=False)
     email = Column(String(30), nullable=False, unique=True)
     password = Column(String(100), nullable=False)
+    active = Column(TINYINT, nullable=False, server_default='0')
 
 
 class UserSchema(Schema):
@@ -24,3 +26,4 @@ class UserSchema(Schema):
     name = fields.String()
     email = fields.String()
     password = fields.String()
+    active = fields.Integer()
